package de.tudarmstadt.maki.simonstrator.api;

import de.tudarmstadt.maki.simonstrator.api.common.graph.INodeID;
import de.tudarmstadt.maki.simonstrator.api.component.ComponentNotAvailableException;
import de.tudarmstadt.maki.simonstrator.api.component.core.NodeDebugMonitorComponent;

import java.util.HashMap;
import java.util.Map;

/**
 * Bridge to local node debug monitoring. Provides logging capabilities and
 * data access for per node information.
 */
public class NodeDebugMonitor
{
    private static NodeDebugMonitorComponent monitor = null;

    private static NodeDebugMonitorComponent getDebugMonitor()
    {
        if(monitor != null) return monitor;

        try {
            return Binder.getComponent(NodeDebugMonitorComponent.class);
        } catch (ComponentNotAvailableException e) {
            throw new AssertionError("NodeDebugMonitorComponent is not available! Did you set in in your config?");
        }
    }

    /**
     * Update the info for a node.
     * @param nodeId id of the node the info belongs to.
     * @param entry The description/key of the entry
     * @param value The value of the entry.
     */
    public static void update(Class<?> subject, INodeID nodeId, String entry, Object value)
    {
        try
        {
            getDebugMonitor().update(subject, nodeId, entry, value);
        }
        catch (AssertionError e)
        {
            //Fail silently
        }

    }

    /**
     * Gets the data of a node separated by the classes the information came from.
     * @param nodeID The node of which the information should be collected.
     * @return A hashmap of hashmaps with each inner hashmap holding the information provided by one
     *              specific class.
     */
    public static Map<Class, HashMap<String, Object>> getNodeData(INodeID nodeID)
    {
        return getDebugMonitor().getNodeData(nodeID);
    }

    /**
     * Add a listener which will be informed about data updates.
     * @param listener The listener to add.
     */
    public static void addUpdateListener(NodeDebugMonitorComponent.NodeDebugUpdateListener listener)
    {
        getDebugMonitor().addUpdateListener(listener);
    }
}

